@@ -13,7 +13,7 @@ static unsigned int _array_length(void* _array)
 }
 
 typedef struct _GArray GArray;
-struct _GArray { uint8_t _data[8]; };
+struct _GArray { uint8_t _data[16]; };
 typedef uint32_t GAsciiType;
 typedef struct _GAsyncQueue GAsyncQueue;
 struct _GAsyncQueue {};
@@ -21,7 +21,7 @@ typedef struct _GBookmarkFile GBookmarkFile;
 struct _GBookmarkFile {};
 typedef uint32_t GBookmarkFileError;
 typedef struct _GByteArray GByteArray;
-struct _GByteArray { uint8_t _data[8]; };
+struct _GByteArray { uint8_t _data[16]; };
 typedef struct _GBytes GBytes;
 struct _GBytes {};
 typedef struct _GChecksum GChecksum;
@@ -32,7 +32,7 @@ typedef void* GClearHandleFunc;
 typedef void* GCompareDataFunc;
 typedef void* GCompareFunc;
 typedef struct _GCond GCond;
-struct _GCond { uint8_t _data[12]; };
+struct _GCond { uint8_t _data[16]; };
 typedef uint32_t GConvertError;
 typedef void* GCopyFunc;
 typedef struct _GData GData;
@@ -46,7 +46,7 @@ typedef struct _GDateTime GDateTime;
 struct _GDateTime {};
 typedef uint32_t GDateWeekday;
 typedef struct _GDebugKey GDebugKey;
-struct _GDebugKey { uint8_t _data[8]; };
+struct _GDebugKey { uint8_t _data[16]; };
 typedef void* GDestroyNotify;
 typedef struct _GDir GDir;
 struct _GDir {};
@@ -55,7 +55,7 @@ struct _GDoubleIEEE754 { uint8_t _data[8]; };
 typedef void* GDuplicateFunc;
 typedef void* GEqualFunc;
 typedef struct _GError GError;
-struct _GError { uint8_t _data[12]; };
+struct _GError { uint8_t _data[16]; };
 typedef uint32_t GErrorType;
 typedef uint32_t GFileError;
 typedef uint32_t GFileTest;
@@ -70,11 +70,11 @@ typedef void* GHashFunc;
 typedef struct _GHashTable GHashTable;
 struct _GHashTable {};
 typedef struct _GHashTableIter GHashTableIter;
-struct _GHashTableIter { uint8_t _data[24]; };
+struct _GHashTableIter { uint8_t _data[40]; };
 typedef struct _GHmac GHmac;
 struct _GHmac {};
 typedef struct _GHook GHook;
-struct _GHook { uint8_t _data[32]; };
+struct _GHook { uint8_t _data[64]; };
 typedef void* GHookCheckFunc;
 typedef void* GHookCheckMarshaller;
 typedef void* GHookCompareFunc;
@@ -83,26 +83,26 @@ typedef void* GHookFindFunc;
 typedef uint32_t GHookFlagMask;
 typedef void* GHookFunc;
 typedef struct _GHookList GHookList;
-struct _GHookList { uint8_t _data[32]; };
+struct _GHookList { uint8_t _data[56]; };
 typedef void* GHookMarshaller;
 typedef struct _GIOChannel GIOChannel;
-struct _GIOChannel { uint8_t _data[84]; };
+struct _GIOChannel { uint8_t _data[136]; };
 typedef uint32_t GIOChannelError;
 typedef uint32_t GIOCondition;
 typedef uint32_t GIOError;
 typedef uint32_t GIOFlags;
 typedef void* GIOFunc;
 typedef struct _GIOFuncs GIOFuncs;
-struct _GIOFuncs { uint8_t _data[32]; };
+struct _GIOFuncs { uint8_t _data[64]; };
 typedef uint32_t GIOStatus;
 typedef struct _GKeyFile GKeyFile;
 struct _GKeyFile {};
 typedef uint32_t GKeyFileError;
 typedef uint32_t GKeyFileFlags;
 typedef struct _GList GList;
-struct _GList { uint8_t _data[12]; };
+struct _GList { uint8_t _data[24]; };
 typedef struct _GLogField GLogField;
-struct _GLogField { uint8_t _data[12]; };
+struct _GLogField { uint8_t _data[24]; };
 typedef void* GLogFunc;
 typedef int32_t GLogLevelFlags;
 typedef void* GLogWriterFunc;
@@ -119,28 +119,28 @@ typedef struct _GMarkupParseContext GMarkupParseContext;
 struct _GMarkupParseContext {};
 typedef uint32_t GMarkupParseFlags;
 typedef struct _GMarkupParser GMarkupParser;
-struct _GMarkupParser { uint8_t _data[20]; };
+struct _GMarkupParser { uint8_t _data[40]; };
 typedef struct _GMatchInfo GMatchInfo;
 struct _GMatchInfo {};
 typedef struct _GMemVTable GMemVTable;
-struct _GMemVTable { uint8_t _data[24]; };
+struct _GMemVTable { uint8_t _data[48]; };
 typedef struct _GMutex GMutex;
 struct _GMutex { uint8_t _data[8]; };
 typedef struct _GNode GNode;
-struct _GNode { uint8_t _data[20]; };
+struct _GNode { uint8_t _data[40]; };
 typedef void* GNodeForeachFunc;
 typedef void* GNodeTraverseFunc;
 typedef uint32_t GNormalizeMode;
 typedef uint32_t GNumberParserError;
 typedef struct _GOnce GOnce;
-struct _GOnce { uint8_t _data[8]; };
+struct _GOnce { uint8_t _data[16]; };
 typedef uint32_t GOnceStatus;
 typedef uint32_t GOptionArg;
 typedef void* GOptionArgFunc;
 typedef struct _GOptionContext GOptionContext;
 struct _GOptionContext {};
 typedef struct _GOptionEntry GOptionEntry;
-struct _GOptionEntry { uint8_t _data[28]; };
+struct _GOptionEntry { uint8_t _data[48]; };
 typedef uint32_t GOptionError;
 typedef void* GOptionErrorFunc;
 typedef uint32_t GOptionFlags;
@@ -154,17 +154,17 @@ struct _GPollFD { uint8_t _data[8]; };
 typedef void* GPollFunc;
 typedef void* GPrintFunc;
 typedef struct _GPrivate GPrivate;
-struct _GPrivate { uint8_t _data[16]; };
+struct _GPrivate { uint8_t _data[32]; };
 typedef struct _GPtrArray GPtrArray;
-struct _GPtrArray { uint8_t _data[8]; };
+struct _GPtrArray { uint8_t _data[16]; };
 typedef struct _GQueue GQueue;
-struct _GQueue { uint8_t _data[12]; };
+struct _GQueue { uint8_t _data[24]; };
 typedef struct _GRWLock GRWLock;
-struct _GRWLock { uint8_t _data[12]; };
+struct _GRWLock { uint8_t _data[16]; };
 typedef struct _GRand GRand;
 struct _GRand {};
 typedef struct _GRecMutex GRecMutex;
-struct _GRecMutex { uint8_t _data[12]; };
+struct _GRecMutex { uint8_t _data[16]; };
 typedef struct _GRegex GRegex;
 struct _GRegex {};
 typedef uint32_t GRegexCompileFlags;
@@ -172,11 +172,11 @@ typedef uint32_t GRegexError;
 typedef void* GRegexEvalCallback;
 typedef uint32_t GRegexMatchFlags;
 typedef struct _GSList GSList;
-struct _GSList { uint8_t _data[8]; };
+struct _GSList { uint8_t _data[16]; };
 typedef struct _GScanner GScanner;
-struct _GScanner { uint8_t _data[104]; };
+struct _GScanner { uint8_t _data[144]; };
 typedef struct _GScannerConfig GScannerConfig;
-struct _GScannerConfig { uint8_t _data[108]; };
+struct _GScannerConfig { uint8_t _data[128]; };
 typedef void* GScannerMsgFunc;
 typedef uint32_t GSeekType;
 typedef struct _GSequence GSequence;
@@ -187,13 +187,13 @@ typedef void* GSequenceIterCompareFunc;
 typedef uint32_t GShellError;
 typedef uint32_t GSliceConfig;
 typedef struct _GSource GSource;
-struct _GSource { uint8_t _data[52]; };
+struct _GSource { uint8_t _data[96]; };
 typedef struct _GSourceCallbackFuncs GSourceCallbackFuncs;
-struct _GSourceCallbackFuncs { uint8_t _data[12]; };
+struct _GSourceCallbackFuncs { uint8_t _data[24]; };
 typedef void* GSourceDummyMarshal;
 typedef void* GSourceFunc;
 typedef struct _GSourceFuncs GSourceFuncs;
-struct _GSourceFuncs { uint8_t _data[24]; };
+struct _GSourceFuncs { uint8_t _data[48]; };
 typedef struct _GSourcePrivate GSourcePrivate;
 struct _GSourcePrivate {};
 typedef void* GSpawnChildSetupFunc;
@@ -202,7 +202,7 @@ typedef uint32_t GSpawnFlags;
 typedef struct _GStatBuf GStatBuf;
 struct _GStatBuf {};
 typedef struct _GString GString;
-struct _GString { uint8_t _data[12]; };
+struct _GString { uint8_t _data[24]; };
 typedef struct _GStringChunk GStringChunk;
 struct _GStringChunk {};
 typedef struct _GTestCase GTestCase;
@@ -214,10 +214,10 @@ typedef uint32_t GTestFileType;
 typedef void* GTestFixtureFunc;
 typedef void* GTestFunc;
 typedef struct _GTestLogBuffer GTestLogBuffer;
-struct _GTestLogBuffer { uint8_t _data[8]; };
+struct _GTestLogBuffer { uint8_t _data[16]; };
 typedef void* GTestLogFatalFunc;
 typedef struct _GTestLogMsg GTestLogMsg;
-struct _GTestLogMsg { uint8_t _data[20]; };
+struct _GTestLogMsg { uint8_t _data[32]; };
 typedef uint32_t GTestLogType;
 typedef uint32_t GTestResult;
 typedef uint32_t GTestSubprocessFlags;
@@ -229,10 +229,10 @@ struct _GThread {};
 typedef uint32_t GThreadError;
 typedef void* GThreadFunc;
 typedef struct _GThreadPool GThreadPool;
-struct _GThreadPool { uint8_t _data[12]; };
+struct _GThreadPool { uint8_t _data[24]; };
 typedef uint32_t GTimeType;
 typedef struct _GTimeVal GTimeVal;
-struct _GTimeVal { uint8_t _data[8]; };
+struct _GTimeVal { uint8_t _data[16]; };
 typedef struct _GTimeZone GTimeZone;
 struct _GTimeZone {};
 typedef struct _GTimer GTimer;
@@ -242,7 +242,7 @@ typedef struct _GTokenValue GTokenValue;
 struct _GTokenValue { uint8_t _data[8]; };
 typedef void* GTranslateFunc;
 typedef struct _GTrashStack GTrashStack;
-struct _GTrashStack { uint8_t _data[4]; };
+struct _GTrashStack { uint8_t _data[8]; };
 typedef uint32_t GTraverseFlags;
 typedef void* GTraverseFunc;
 typedef uint32_t GTraverseType;
@@ -398,7 +398,7 @@ extern void g_closure_sink(GClosure*);
 extern void g_closure_unref(GClosure*);
 extern GType g_initially_unowned_get_type();
 extern GObject* g_object_newv(GType, uint32_t, GParameter*);
-extern uint32_t g_object_compat_control(uint32_t, void*);
+extern uint64_t g_object_compat_control(uint64_t, void*);
 extern GParamSpec* g_object_interface_find_property(GTypeInterface*, char*);
 extern void g_object_interface_install_property(GTypeInterface*, GParamSpec*);
 extern GParamSpec** g_object_interface_list_properties(GTypeInterface*, uint32_t*);
@@ -469,7 +469,7 @@ extern GType intern();
 extern GType intern();
 extern GType intern();
 extern GType intern();
-extern void g_type_class_add_private(GTypeClass*, uint32_t);
+extern void g_type_class_add_private(GTypeClass*, uint64_t);
 extern void* g_type_class_get_private(GTypeClass*, GType);
 extern GTypeClass* g_type_class_peek_parent(GTypeClass*);
 extern void g_type_class_unref(GTypeClass*);
@@ -511,7 +511,7 @@ extern float g_value_get_float(GValue*);
 extern GType g_value_get_gtype(GValue*);
 extern int32_t g_value_get_int(GValue*);
 extern int64_t g_value_get_int64(GValue*);
-extern int32_t g_value_get_long(GValue*);
+extern int64_t g_value_get_long(GValue*);
 extern GObject* g_value_get_object(GValue*);
 extern GParamSpec* g_value_get_param(GValue*);
 extern void* g_value_get_pointer(GValue*);
@@ -520,7 +520,7 @@ extern char* g_value_get_string(GValue*);
 extern uint8_t g_value_get_uchar(GValue*);
 extern uint32_t g_value_get_uint(GValue*);
 extern uint64_t g_value_get_uint64(GValue*);
-extern uint32_t g_value_get_ulong(GValue*);
+extern uint64_t g_value_get_ulong(GValue*);
 extern GVariant* g_value_get_variant(GValue*);
 extern GValue* g_value_init(GValue*, GType);
 extern void g_value_init_from_instance(GValue*, GTypeInstance*);
@@ -538,7 +538,7 @@ extern void g_value_set_gtype(GValue*, GType);
 extern void g_value_set_instance(GValue*, void*);
 extern void g_value_set_int(GValue*, int32_t);
 extern void g_value_set_int64(GValue*, int64_t);
-extern void g_value_set_long(GValue*, int32_t);
+extern void g_value_set_long(GValue*, int64_t);
 extern void g_value_set_object(GValue*, GObject*);
 extern void g_value_set_param(GValue*, GParamSpec*);
 extern void g_value_set_pointer(GValue*, void*);
@@ -550,7 +550,7 @@ extern void g_value_set_string_take_ownership(GValue*, char*);
 extern void g_value_set_uchar(GValue*, uint8_t);
 extern void g_value_set_uint(GValue*, uint32_t);
 extern void g_value_set_uint64(GValue*, uint64_t);
-extern void g_value_set_ulong(GValue*, uint32_t);
+extern void g_value_set_ulong(GValue*, uint64_t);
 extern void g_value_set_variant(GValue*, GVariant*);
 extern void g_value_take_boxed(GValue*, void*);
 extern void g_value_take_string(GValue*, char*);
@@ -592,7 +592,7 @@ extern GParamSpec* g_param_spec_float(char*, char*, char*, float, float, float,
 extern GParamSpec* g_param_spec_gtype(char*, char*, char*, GType, GParamFlags);
 extern GParamSpec* g_param_spec_int(char*, char*, char*, int32_t, int32_t, int32_t, GParamFlags);
 extern GParamSpec* g_param_spec_int64(char*, char*, char*, int64_t, int64_t, int64_t, GParamFlags);
-extern GParamSpec* g_param_spec_long(char*, char*, char*, int32_t, int32_t, int32_t, GParamFlags);
+extern GParamSpec* g_param_spec_long(char*, char*, char*, int64_t, int64_t, int64_t, GParamFlags);
 extern GParamSpec* g_param_spec_object(char*, char*, char*, GType, GParamFlags);
 extern GParamSpec* g_param_spec_param(char*, char*, char*, GType, GParamFlags);
 extern GParamSpec* g_param_spec_pointer(char*, char*, char*, GParamFlags);
@@ -600,7 +600,7 @@ extern GParamSpec* g_param_spec_string(char*, char*, char*, char*, GParamFlags);
 extern GParamSpec* g_param_spec_uchar(char*, char*, char*, uint8_t, uint8_t, uint8_t, GParamFlags);
 extern GParamSpec* g_param_spec_uint(char*, char*, char*, uint32_t, uint32_t, uint32_t, GParamFlags);
 extern GParamSpec* g_param_spec_uint64(char*, char*, char*, uint64_t, uint64_t, uint64_t, GParamFlags);
-extern GParamSpec* g_param_spec_ulong(char*, char*, char*, uint32_t, uint32_t, uint32_t, GParamFlags);
+extern GParamSpec* g_param_spec_ulong(char*, char*, char*, uint64_t, uint64_t, uint64_t, GParamFlags);
 extern GParamSpec* g_param_spec_unichar(char*, char*, char*, uint32_t, GParamFlags);
 extern GParamSpec* g_param_spec_variant(char*, char*, char*, GVariantType*, GVariant*, GParamFlags);
 extern GType g_param_type_register_static(char*, GParamSpecTypeInfo*);
@@ -612,17 +612,17 @@ extern int32_t g_param_values_cmp(GParamSpec*, GValue*, GValue*);
 extern GType g_pointer_type_register_static(char*);
 extern int g_signal_accumulator_first_wins(GSignalInvocationHint*, GValue*, GValue*, void*);
 extern int g_signal_accumulator_true_handled(GSignalInvocationHint*, GValue*, GValue*, void*);
-extern uint32_t g_signal_add_emission_hook(uint32_t, uint32_t, GSignalEmissionHook, void*, GDestroyNotify);
+extern uint64_t g_signal_add_emission_hook(uint32_t, uint32_t, GSignalEmissionHook, void*, GDestroyNotify);
 extern void g_signal_chain_from_overridden(GValue*, GValue*);
-extern uint32_t g_signal_connect_closure(GObject*, char*, GClosure*, int);
-extern uint32_t g_signal_connect_closure_by_id(GObject*, uint32_t, uint32_t, GClosure*, int);
+extern uint64_t g_signal_connect_closure(GObject*, char*, GClosure*, int);
+extern uint64_t g_signal_connect_closure_by_id(GObject*, uint32_t, uint32_t, GClosure*, int);
 extern void g_signal_emitv(GValue*, uint32_t, uint32_t, GValue*);
 extern GSignalInvocationHint* g_signal_get_invocation_hint(GObject*);
-extern void g_signal_handler_block(GObject*, uint32_t);
-extern void g_signal_handler_disconnect(GObject*, uint32_t);
-extern uint32_t g_signal_handler_find(GObject*, GSignalMatchType, uint32_t, uint32_t, GClosure*, void*, void*);
-extern int g_signal_handler_is_connected(GObject*, uint32_t);
-extern void g_signal_handler_unblock(GObject*, uint32_t);
+extern void g_signal_handler_block(GObject*, uint64_t);
+extern void g_signal_handler_disconnect(GObject*, uint64_t);
+extern uint64_t g_signal_handler_find(GObject*, GSignalMatchType, uint32_t, uint32_t, GClosure*, void*, void*);
+extern int g_signal_handler_is_connected(GObject*, uint64_t);
+extern void g_signal_handler_unblock(GObject*, uint64_t);
 extern uint32_t g_signal_handlers_block_matched(GObject*, GSignalMatchType, uint32_t, uint32_t, GClosure*, void*, void*);
 extern void g_signal_handlers_destroy(GObject*);
 extern uint32_t g_signal_handlers_disconnect_matched(GObject*, GSignalMatchType, uint32_t, uint32_t, GClosure*, void*, void*);
@@ -634,7 +634,7 @@ extern char* g_signal_name(uint32_t);
 extern void g_signal_override_class_closure(uint32_t, GType, GClosure*);
 extern int g_signal_parse_name(char*, GType, uint32_t*, uint32_t*, int);
 extern void g_signal_query(uint32_t, GSignalQuery*);
-extern void g_signal_remove_emission_hook(uint32_t, uint32_t);
+extern void g_signal_remove_emission_hook(uint32_t, uint64_t);
 extern void g_signal_set_va_marshaller(uint32_t, GType, GVaClosureMarshal);
 extern void g_signal_stop_emission(GObject*, uint32_t, uint32_t);
 extern void g_signal_stop_emission_by_name(GObject*, char*);
@@ -642,8 +642,8 @@ extern GClosure* g_signal_type_cclosure_new(GType, uint32_t);
 extern void g_source_set_closure(GSource*, GClosure*);
 extern void g_source_set_dummy_callback(GSource*);
 extern char* g_strdup_value_contents(GValue*);
-extern void g_type_add_class_private(GType, uint32_t);
-extern int32_t g_type_add_instance_private(GType, uint32_t);
+extern void g_type_add_class_private(GType, uint64_t);
+extern int32_t g_type_add_instance_private(GType, uint64_t);
 extern void g_type_add_interface_dynamic(GType, GType, GTypePlugin*);
 extern void g_type_add_interface_static(GType, GType, GInterfaceInfo*);
 extern int g_type_check_class_is_a(GTypeClass*, GType);
@@ -683,34 +683,34 @@ extern GType g_type_register_fundamental(GType, char*, GTypeInfo*, GTypeFundamen
 extern GType g_type_register_static(GType, char*, GTypeInfo*, GTypeFlags);
 extern void g_type_set_qdata(GType, uint32_t, void*);
 extern int g_type_test_flags(GType, uint32_t);
-struct _GCClosure { uint8_t _data[56]; };
-struct _GClosure { uint8_t _data[52]; };
-struct _GClosureNotifyData { uint8_t _data[8]; };
-struct _GEnumClass { uint8_t _data[20]; };
-struct _GEnumValue { uint8_t _data[12]; };
-struct _GFlagsClass { uint8_t _data[16]; };
-struct _GFlagsValue { uint8_t _data[12]; };
-struct _GInitiallyUnownedClass { uint8_t _data[68]; };
-struct _GInterfaceInfo { uint8_t _data[12]; };
-struct _GObjectClass { uint8_t _data[68]; };
-struct _GObjectConstructParam { uint8_t _data[8]; };
-struct _GParamSpecClass { uint8_t _data[40]; };
+struct _GCClosure { uint8_t _data[72]; };
+struct _GClosure { uint8_t _data[64]; };
+struct _GClosureNotifyData { uint8_t _data[16]; };
+struct _GEnumClass { uint8_t _data[32]; };
+struct _GEnumValue { uint8_t _data[24]; };
+struct _GFlagsClass { uint8_t _data[24]; };
+struct _GFlagsValue { uint8_t _data[24]; };
+struct _GInitiallyUnownedClass { uint8_t _data[136]; };
+struct _GInterfaceInfo { uint8_t _data[24]; };
+struct _GObjectClass { uint8_t _data[136]; };
+struct _GObjectConstructParam { uint8_t _data[16]; };
+struct _GParamSpecClass { uint8_t _data[80]; };
 struct _GParamSpecPool {};
-struct _GParamSpecTypeInfo { uint8_t _data[28]; };
+struct _GParamSpecTypeInfo { uint8_t _data[56]; };
 struct _GParameter { uint8_t _data[32]; };
 struct _GSignalInvocationHint { uint8_t _data[12]; };
-struct _GSignalQuery { uint8_t _data[28]; };
-struct _GTypeCValue { uint8_t _data[8]; };
-struct _GTypeClass { uint8_t _data[4]; };
+struct _GSignalQuery { uint8_t _data[56]; };
+struct _GTypeCValue {};
+struct _GTypeClass { uint8_t _data[8]; };
 struct _GTypeFundamentalInfo { uint8_t _data[4]; };
-struct _GTypeInfo { uint8_t _data[36]; };
-struct _GTypeInstance { uint8_t _data[4]; };
-struct _GTypeInterface { uint8_t _data[8]; };
-struct _GTypeModuleClass { uint8_t _data[92]; };
-struct _GTypePluginClass { uint8_t _data[24]; };
-struct _GTypeQuery { uint8_t _data[16]; };
-struct _GTypeValueTable { uint8_t _data[32]; };
+struct _GTypeInfo { uint8_t _data[72]; };
+struct _GTypeInstance { uint8_t _data[8]; };
+struct _GTypeInterface { uint8_t _data[16]; };
+struct _GTypeModuleClass { uint8_t _data[184]; };
+struct _GTypePluginClass { uint8_t _data[48]; };
+struct _GTypeQuery { uint8_t _data[24]; };
+struct _GTypeValueTable { uint8_t _data[64]; };
 struct _GValue { uint8_t _data[24]; };
-struct _GValueArray { uint8_t _data[12]; };
+struct _GValueArray { uint8_t _data[24]; };
 struct _GWeakRef {};
 struct _G_Value__data__union { uint8_t _data[8]; };
