@@ -635,12 +635,10 @@ type EnumClass struct {
 	Minimum int32
 	Maximum int32
 	NValues uint32
-	_ [4]byte
 	Values *EnumValue
 }
 type EnumValue struct {
 	Value int32
-	_ [4]byte
 	value_name0 *C.char
 	value_nick0 *C.char
 }
@@ -662,7 +660,6 @@ type FlagsClass struct {
 }
 type FlagsValue struct {
 	Value uint32
-	_ [4]byte
 	value_name0 *C.char
 	value_nick0 *C.char
 }
@@ -835,7 +832,6 @@ const (
 type ParamSpecTypeInfo struct {
 	InstanceSize uint16
 	NPreallocs uint16
-	_ [4]byte
 	InstanceInit unsafe.Pointer
 	ValueType Type
 	Finalize unsafe.Pointer
@@ -852,6 +848,7 @@ type ParamSpecTypeInfo struct {
 // blacklisted: ParamSpecVariant (object)
 type Parameter struct {
 	name0 *C.char
+	_ [4]byte
 	Value Value
 }
 func (this0 *Parameter) Name() string {
@@ -891,14 +888,11 @@ const (
 )
 type SignalQuery struct {
 	SignalId uint32
-	_ [4]byte
 	signal_name0 *C.char
 	Itype Type
 	SignalFlags SignalFlags
-	_ [4]byte
 	ReturnType Type
 	NParams uint32
-	_ [4]byte
 	param_types0 *C.GType
 }
 func (this0 *SignalQuery) SignalName() string {
@@ -923,16 +917,16 @@ const TypeReservedGlibLast = 31
 const TypeReservedUserFirst = 49
 // blacklisted: ToggleNotify (callback)
 type TypeCValue struct {
-	_data [8]byte
+	_data [0]byte
 }
 type TypeClass struct {
 	GType Type
 }
-func (this0 *TypeClass) AddPrivate(private_size0 uint64) {
+func (this0 *TypeClass) AddPrivate(private_size0 uint32) {
 	var this1 *C.GTypeClass
-	var private_size1 C.uint64_t
+	var private_size1 C.uint32_t
 	this1 = (*C.GTypeClass)(unsafe.Pointer(this0))
-	private_size1 = C.uint64_t(private_size0)
+	private_size1 = C.uint32_t(private_size0)
 	C.g_type_class_add_private(this1, private_size1)
 }
 func (this0 *TypeClass) GetPrivate(private_type0 Type) {
@@ -1005,7 +999,7 @@ type TypeFundamentalInfo struct {
 }
 type TypeInfo struct {
 	ClassSize uint16
-	_ [6]byte
+	_ [2]byte
 	BaseInit unsafe.Pointer
 	BaseFinalize unsafe.Pointer
 	ClassInit unsafe.Pointer
@@ -1013,7 +1007,6 @@ type TypeInfo struct {
 	ClassData unsafe.Pointer
 	InstanceSize uint16
 	NPreallocs uint16
-	_ [4]byte
 	InstanceInit unsafe.Pointer
 	ValueTable *TypeValueTable
 }
@@ -1204,18 +1197,16 @@ func (this0 *TypeValueTable) LcopyFormat() string {
 	lcopy_format1 = C.GoString(this0.lcopy_format0)
 	return lcopy_format1
 }
-const ValueCollectFormatMaxLength = 8
 const ValueNocopyContents = 134217728
 type Value struct {
 	GType Type
+	_ [4]byte
 	Data [2]_Value__data__union
 }
 type ValueArray struct {
 	NValues uint32
-	_ [4]byte
 	Values *Value
 	NPrealloced uint32
-	_ [4]byte
 }
 func NewValueArray(n_prealloced0 uint32) *ValueArray {
 	var n_prealloced1 C.uint32_t
